/*
*******************************************************************************
**
**  This device driver was created by Applilet for the 78K0S/KB1+, 78K0S/KA1+,
**  78K0S/KY1+ 8-Bit Single-Chip Microcontrollers.
**
**  Copyright(C) NEC Electronics Corporation 2002-2005
**  All rights reserved by NEC Electronics Corporation.
**
**  This program should be used on your own responsibility.
**  NEC Electronics Corporation assumes no responsibility for any losses
**  incurred by customers or third parties arising from the use of this file.
**
**  Filename :	ad.c
**  Abstract :	This file implements device driver for AD module.
**  APIlib :	NEC78K0SKX1+.lib E1.46f [30 Sep. 2005]
**
**  Device :	uPD78F9222
**
**  Compiler :	NEC/CC78K0
**
*******************************************************************************
*/
/*
*******************************************************************************
**  Include files
*******************************************************************************
*/
#include "macrodriver.h"
#include "ad.h"
/*
*******************************************************************************
**  MacroDefine
*******************************************************************************
*/

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function initializes the A/D converter.
**
**  Parameters:
**	None
**
**  Returns:
**	None
**
**-----------------------------------------------------------------------------
*/
void AD_Init( void )
{
	PMC2 |= 0x2;			/* P21/ANI1 input */
	PM2 |= 0x2;
	SetIORBit(ADM, 0x38);		/* conversion time 224/fx */
	ClrIORBit(IF0, 0x80);
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function starts the A/D converter.
**
**  Parameters:
**	channel :	enum ADChannel
**
**  Returns:
**	MD_OK
**
**-----------------------------------------------------------------------------
*/
MD_STATUS AD_Start( enum ADChannel channel )
{
	int delay = 200;
	
	ADS = channel;
	ClrIORBit(MK0, 0x80);			/* enable interrupt */
	SetIORBit(ADM, 0x01);
	while(delay--);
	SetIORBit(ADM, 0x80);
	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function returns conversion result in the buffer.
**
**  Parameters:
**	buffer :	the address to store conversion result
**
**  Returns:
**	MD_OK
**
**-----------------------------------------------------------------------------
*/
MD_STATUS AD_Read( USHORT* buffer )
{
	*buffer = (USHORT)( ADCR );
	return MD_OK;
}

/*
**-----------------------------------------------------------------------------
**
**  Abstract:
**	This function stops the A/D converter.
**
**  Parameters:
**	None
**
**  Returns:
**	MD_OK
**
**-----------------------------------------------------------------------------
*/
MD_STATUS AD_Stop( void )
{
	SetIORBit(MK0, 0x80);			/* disable interrupt */
	ClrIORBit(ADM, 0x81);
	return MD_OK;
}
